==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachineInstancePropertiesStorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * StorageProfile - contains information about the disks and storage information for the virtual machine instance
 * @property dataDisks adds data disks to the virtual machine instance
 * @property imageReference Which Image to use for the virtual machine instance
 * @property osDisk VHD to attach as OS disk
 * @property vmConfigStoragePathId Id of the storage container that hosts the VM configuration file
 */
public data class VirtualMachineInstancePropertiesStorageProfileArgs(
    public val dataDisks: Output<List<VirtualMachineInstancePropertiesDataDisksArgs>>? = null,
    public val imageReference: Output<VirtualMachineInstancePropertiesImageReferenceArgs>? = null,
    public val osDisk: Output<VirtualMachineInstancePropertiesOsDiskArgs>? = null,
    public val vmConfigStoragePathId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs.builder()
            .dataDisks(
                dataDisks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .imageReference(imageReference?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .osDisk(osDisk?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .vmConfigStoragePathId(vmConfigStoragePathId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineInstancePropertiesStorageProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachineInstancePropertiesStorageProfileArgsBuilder internal constructor() {
    private var dataDisks: Output<List<VirtualMachineInstancePropertiesDataDisksArgs>>? = null

    private var imageReference: Output<VirtualMachineInstancePropertiesImageReferenceArgs>? = null

    private var osDisk: Output<VirtualMachineInstancePropertiesOsDiskArgs>? = null

    private var vmConfigStoragePathId: Output<String>? = null

    /**
     * @param value adds data disks to the virtual machine instance
     */
    @JvmName("smgklxwkrscxjnob")
    public suspend
    fun dataDisks(`value`: Output<List<VirtualMachineInstancePropertiesDataDisksArgs>>) {
        this.dataDisks = value
    }

    @JvmName("gspxdgdjyepcqfee")
    public suspend fun dataDisks(
        vararg
        values: Output<VirtualMachineInstancePropertiesDataDisksArgs>,
    ) {
        this.dataDisks = Output.all(values.asList())
    }

    /**
     * @param values adds data disks to the virtual machine instance
     */
    @JvmName("molosvfkdtccccel")
    public suspend
    fun dataDisks(values: List<Output<VirtualMachineInstancePropertiesDataDisksArgs>>) {
        this.dataDisks = Output.all(values)
    }

    /**
     * @param value Which Image to use for the virtual machine instance
     */
    @JvmName("owvirlkuanprxjob")
    public suspend
    fun imageReference(`value`: Output<VirtualMachineInstancePropertiesImageReferenceArgs>) {
        this.imageReference = value
    }

    /**
     * @param value VHD to attach as OS disk
     */
    @JvmName("ygnasbgedpswuagy")
    public suspend fun osDisk(`value`: Output<VirtualMachineInstancePropertiesOsDiskArgs>) {
        this.osDisk = value
    }

    /**
     * @param value Id of the storage container that hosts the VM configuration file
     */
    @JvmName("qvbksikdfrsiaoxb")
    public suspend fun vmConfigStoragePathId(`value`: Output<String>) {
        this.vmConfigStoragePathId = value
    }

    /**
     * @param value adds data disks to the virtual machine instance
     */
    @JvmName("fgvpruadeoofoxvf")
    public suspend fun dataDisks(`value`: List<VirtualMachineInstancePropertiesDataDisksArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param argument adds data disks to the virtual machine instance
     */
    @JvmName("jwkhfipvvaaddhei")
    public suspend
    fun dataDisks(argument: List<suspend VirtualMachineInstancePropertiesDataDisksArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineInstancePropertiesDataDisksArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument adds data disks to the virtual machine instance
     */
    @JvmName("bfvlyaelqttplhye")
    public suspend fun dataDisks(
        vararg
        argument: suspend VirtualMachineInstancePropertiesDataDisksArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineInstancePropertiesDataDisksArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument adds data disks to the virtual machine instance
     */
    @JvmName("gbivehdrssvushes")
    public suspend
    fun dataDisks(argument: suspend VirtualMachineInstancePropertiesDataDisksArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineInstancePropertiesDataDisksArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param values adds data disks to the virtual machine instance
     */
    @JvmName("ynhehsnivjuvtxsp")
    public suspend fun dataDisks(vararg values: VirtualMachineInstancePropertiesDataDisksArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param value Which Image to use for the virtual machine instance
     */
    @JvmName("grsmwsmefvleiqid")
    public suspend fun imageReference(`value`: VirtualMachineInstancePropertiesImageReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageReference = mapped
    }

    /**
     * @param argument Which Image to use for the virtual machine instance
     */
    @JvmName("cfkyjrgjdhlsogpa")
    public suspend
    fun imageReference(argument: suspend VirtualMachineInstancePropertiesImageReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachineInstancePropertiesImageReferenceArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.imageReference = mapped
    }

    /**
     * @param value VHD to attach as OS disk
     */
    @JvmName("ytqiamgkftueoape")
    public suspend fun osDisk(`value`: VirtualMachineInstancePropertiesOsDiskArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osDisk = mapped
    }

    /**
     * @param argument VHD to attach as OS disk
     */
    @JvmName("wlfmwpnyjudhtnxu")
    public suspend
    fun osDisk(argument: suspend VirtualMachineInstancePropertiesOsDiskArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachineInstancePropertiesOsDiskArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.osDisk = mapped
    }

    /**
     * @param value Id of the storage container that hosts the VM configuration file
     */
    @JvmName("soovkqxstpendoxo")
    public suspend fun vmConfigStoragePathId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmConfigStoragePathId = mapped
    }

    internal fun build(): VirtualMachineInstancePropertiesStorageProfileArgs =
        VirtualMachineInstancePropertiesStorageProfileArgs(
            dataDisks = dataDisks,
            imageReference = imageReference,
            osDisk = osDisk,
            vmConfigStoragePathId = vmConfigStoragePathId,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurestackhci/kotlin/inputs/VirtualMachineInstancePropertiesStorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestackhci.kotlin.inputs

import com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * StorageProfile - contains information about the disks and storage information for the virtual machine instance
 * @property dataDisks adds data disks to the virtual machine instance
 * @property imageReference Which Image to use for the virtual machine instance
 * @property osDisk VHD to attach as OS disk
 * @property vmConfigStoragePathId Id of the storage container that hosts the VM configuration file
 */
public data class VirtualMachineInstancePropertiesStorageProfileArgs(
    public val dataDisks: Output<List<VirtualMachineInstancePropertiesDataDisksArgs>>? = null,
    public val imageReference: Output<VirtualMachineInstancePropertiesImageReferenceArgs>? = null,
    public val osDisk: Output<VirtualMachineInstancePropertiesOsDiskArgs>? = null,
    public val vmConfigStoragePathId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs =
        com.pulumi.azurenative.azurestackhci.inputs.VirtualMachineInstancePropertiesStorageProfileArgs.builder()
            .dataDisks(
                dataDisks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .imageReference(imageReference?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .osDisk(osDisk?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .vmConfigStoragePathId(vmConfigStoragePathId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineInstancePropertiesStorageProfileArgs].
 */
@PulumiTagMarker
public class VirtualMachineInstancePropertiesStorageProfileArgsBuilder internal constructor() {
    private var dataDisks: Output<List<VirtualMachineInstancePropertiesDataDisksArgs>>? = null

    private var imageReference: Output<VirtualMachineInstancePropertiesImageReferenceArgs>? = null

    private var osDisk: Output<VirtualMachineInstancePropertiesOsDiskArgs>? = null

    private var vmConfigStoragePathId: Output<String>? = null

    /**
     * @param value adds data disks to the virtual machine instance
     */
    @JvmName("uvjcvkxkjocpdqif")
    public suspend
    fun dataDisks(`value`: Output<List<VirtualMachineInstancePropertiesDataDisksArgs>>) {
        this.dataDisks = value
    }

    @JvmName("pewpulqwvwwwkqen")
    public suspend fun dataDisks(
        vararg
        values: Output<VirtualMachineInstancePropertiesDataDisksArgs>,
    ) {
        this.dataDisks = Output.all(values.asList())
    }

    /**
     * @param values adds data disks to the virtual machine instance
     */
    @JvmName("qaqcddjfsacgqhbo")
    public suspend
    fun dataDisks(values: List<Output<VirtualMachineInstancePropertiesDataDisksArgs>>) {
        this.dataDisks = Output.all(values)
    }

    /**
     * @param value Which Image to use for the virtual machine instance
     */
    @JvmName("dcldavaclemmhbbh")
    public suspend
    fun imageReference(`value`: Output<VirtualMachineInstancePropertiesImageReferenceArgs>) {
        this.imageReference = value
    }

    /**
     * @param value VHD to attach as OS disk
     */
    @JvmName("hkgrqpelegvrqlbc")
    public suspend fun osDisk(`value`: Output<VirtualMachineInstancePropertiesOsDiskArgs>) {
        this.osDisk = value
    }

    /**
     * @param value Id of the storage container that hosts the VM configuration file
     */
    @JvmName("mscpienjxeotathk")
    public suspend fun vmConfigStoragePathId(`value`: Output<String>) {
        this.vmConfigStoragePathId = value
    }

    /**
     * @param value adds data disks to the virtual machine instance
     */
    @JvmName("vjglnlcvnqtuuool")
    public suspend fun dataDisks(`value`: List<VirtualMachineInstancePropertiesDataDisksArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param argument adds data disks to the virtual machine instance
     */
    @JvmName("wlkvnutddoxahfdq")
    public suspend
    fun dataDisks(argument: List<suspend VirtualMachineInstancePropertiesDataDisksArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineInstancePropertiesDataDisksArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument adds data disks to the virtual machine instance
     */
    @JvmName("tyqviafemgbdwaym")
    public suspend fun dataDisks(
        vararg
        argument: suspend VirtualMachineInstancePropertiesDataDisksArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineInstancePropertiesDataDisksArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param argument adds data disks to the virtual machine instance
     */
    @JvmName("xvrajcgwbtytxlry")
    public suspend
    fun dataDisks(argument: suspend VirtualMachineInstancePropertiesDataDisksArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineInstancePropertiesDataDisksArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dataDisks = mapped
    }

    /**
     * @param values adds data disks to the virtual machine instance
     */
    @JvmName("vtaflkyupquycinh")
    public suspend fun dataDisks(vararg values: VirtualMachineInstancePropertiesDataDisksArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDisks = mapped
    }

    /**
     * @param value Which Image to use for the virtual machine instance
     */
    @JvmName("xdpbvxuncbvjflba")
    public suspend fun imageReference(`value`: VirtualMachineInstancePropertiesImageReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageReference = mapped
    }

    /**
     * @param argument Which Image to use for the virtual machine instance
     */
    @JvmName("ycndvlewkfstlfyi")
    public suspend
    fun imageReference(argument: suspend VirtualMachineInstancePropertiesImageReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachineInstancePropertiesImageReferenceArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.imageReference = mapped
    }

    /**
     * @param value VHD to attach as OS disk
     */
    @JvmName("jxwnvrdrseaboswg")
    public suspend fun osDisk(`value`: VirtualMachineInstancePropertiesOsDiskArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osDisk = mapped
    }

    /**
     * @param argument VHD to attach as OS disk
     */
    @JvmName("uigmynfgsncwcgba")
    public suspend
    fun osDisk(argument: suspend VirtualMachineInstancePropertiesOsDiskArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualMachineInstancePropertiesOsDiskArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.osDisk = mapped
    }

    /**
     * @param value Id of the storage container that hosts the VM configuration file
     */
    @JvmName("wyonqfhbcwhvedji")
    public suspend fun vmConfigStoragePathId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmConfigStoragePathId = mapped
    }

    internal fun build(): VirtualMachineInstancePropertiesStorageProfileArgs =
        VirtualMachineInstancePropertiesStorageProfileArgs(
            dataDisks = dataDisks,
            imageReference = imageReference,
            osDisk = osDisk,
            vmConfigStoragePathId = vmConfigStoragePathId,
        )
}
